@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,15 +25,18 @@
 
 #include <mapnik/util/noncopyable.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_rasterizer_scanline_aa.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace mapnik {
 
-struct grid_rasterizer :  agg::rasterizer_scanline_aa<>, util::noncopyable {};
+struct grid_rasterizer : agg::rasterizer_scanline_aa<>,
+                         util::noncopyable
+{};
 
-}
+} // namespace mapnik
 
-#endif //MAPNIK_AGG_RASTERIZER_HPP
+#endif // MAPNIK_AGG_RASTERIZER_HPP
