@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,8 +29,7 @@
 #include <vector>
 #include <memory>
 
-namespace mapnik
-{
+namespace mapnik {
 struct group_rule;
 using group_rule_ptr = std::shared_ptr<group_rule>;
 using group_rules = std::vector<group_rule_ptr>;
@@ -38,25 +37,27 @@ using group_rules = std::vector<group_rule_ptr>;
 /** Contains all group symbolizer properties related to building a group layout. */
 struct group_symbolizer_properties
 {
-    inline group_symbolizer_properties() : rules_() { }
+    inline group_symbolizer_properties()
+        : rules_()
+    {}
     /** Load all values from XML ptree. */
-    //void from_xml(xml_node const &sym, fontset_map const & fontsets);
+    // void from_xml(xml_node const &sym, fontset_map const & fontsets);
     /** Get the layout. */
     inline group_layout const& get_layout() const { return layout_; }
     /** Get the group rules. */
     inline group_rules const& get_rules() const { return rules_; }
     /** Set the layout. */
-    inline void set_layout (group_layout && layout) { layout_ = std::move(layout); }
+    inline void set_layout(group_layout&& layout) { layout_ = std::move(layout); }
     /** Add add group rule. */
-    inline void add_rule (group_rule_ptr rule) { rules_.push_back(rule); }
+    inline void add_rule(group_rule_ptr rule) { rules_.push_back(rule); }
 
-private:
+  private:
     group_layout layout_;
-    group_rules  rules_;
+    group_rules rules_;
 };
 
 using group_symbolizer_properties_ptr = std::shared_ptr<group_symbolizer_properties>;
 
-} //ns mapnik
+} // namespace mapnik
 
 #endif // GROUP_PROPERTIES_HPP
