@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,11 +20,18 @@
  *
  *****************************************************************************/
 
-namespace mapnik { namespace util {
+namespace mapnik {
+namespace util {
 
-constexpr unsigned name_to_int(const char *str, int off = 0)
+constexpr unsigned name_to_int(const char* str, unsigned off = 0)
 {
     return !str[off] ? 5381 : (name_to_int(str, off + 1) * 33) ^ static_cast<unsigned>(str[off]);
 }
 
-}}
+constexpr unsigned operator"" _case(char const* str, std::size_t)
+{
+    return name_to_int(str);
+}
+
+} // namespace util
+} // namespace mapnik
