@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,15 +22,17 @@
 
 // mapnik
 #include <mapnik/wkt/wkt_generator_grammar.hpp>
-#include <mapnik/geometry_fusion_adapted.hpp>
+#include <mapnik/geometry/fusion_adapted.hpp>
 
-namespace mapnik { namespace wkt {
+namespace mapnik {
+namespace wkt {
 
-template <typename OutputIterator, typename Geometry>
+template<typename OutputIterator, typename Geometry>
 wkt_generator_grammar<OutputIterator, Geometry>::wkt_generator_grammar()
     : wkt_generator_grammar::base_type(geometry)
 {
     boost::spirit::karma::lit_type lit;
+    // clang-format off
     geometry =
         point
         |
@@ -46,7 +48,7 @@ wkt_generator_grammar<OutputIterator, Geometry>::wkt_generator_grammar()
         |
         geometry_collection
         |
-        lit("POINT EMPTY FAIL") // special case for geometry_empty
+        lit("POINT EMPTY") // special case for geometry_empty
         ;
 
     point = lit("POINT(") << point_coord << lit(")")
@@ -76,13 +78,13 @@ wkt_generator_grammar<OutputIterator, Geometry>::wkt_generator_grammar()
     linestring_coord = lit('(') << point_coord % lit(',') << lit(')')
         ;
 
-    linear_ring_coord = lit('(') << point_coord % lit(',') << lit(')')
+    linear_ring_coord = lit('(') << point_coord % lit(',') << lit(')');//linestring_coord.alias()
+
+
+    polygon_coord = lit('(') << linear_ring_coord % lit(',') << lit(')');
         ;
 
-    polygon_coord = lit('(') << linear_ring_coord << *(lit(',') << linear_ring_coord)<< lit(')');
-        ;
-
-    multi_point_coord = lit('(') << point_coord % lit(',') << lit(')')
+    multi_point_coord = lit('(') << point_coord % lit(',') << lit(')') //linestring_coord.alias()
         ;
 
     multi_linestring_coord = lit("(") << linestring_coord % lit(',') << lit(")")
@@ -93,7 +95,8 @@ wkt_generator_grammar<OutputIterator, Geometry>::wkt_generator_grammar()
 
     geometries = geometry % lit(',')
         ;
-
+    // clang-format on
 }
 
-}}
+} // namespace wkt
+} // namespace mapnik
